# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-06 21:31
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0027_auto_20170405_2035'),
        ('omCmsMain', '0023_auto_20170326_2143'),
    ]

    operations = [
    ]
