# -*- coding: utf-8 -*-
# Generated by Django 1.11rc1 on 2017-03-26 21:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0022_auto_20170326_1919'),
    ]

    operations = [
        migrations.AddField(
            model_name='contentarticle',
            name='body3',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='body3Image',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='title1',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='title2',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='title3',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='body1',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='body2',
            field=models.TextField(blank=True, null=True),
        ),
    ]
