# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-20 15:40
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0002_auto_20170320_1532'),
    ]

    operations = [
        migrations.CreateModel(
            name='contentArticle',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=150)),
            ],
        ),
        migrations.AlterField(
            model_name='categoryitem',
            name='itemCategory',
            field=models.CharField(max_length=50, unique=True),
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='articleCategory',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='omCmsMain.categoryItem', to_field='itemCategory'),
        ),
    ]
