# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-26 19:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0021_auto_20170326_1906'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteLogoLinkTo',
            field=models.CharField(blank=True, default='', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteLogoText',
            field=models.CharField(blank=True, default='', max_length=50, null=True),
        ),
    ]
