# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-22 22:32
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0014_sitemaininfo_sitetheme'),
    ]

    operations = [
        migrations.AddField(
            model_name='contentarticle',
            name='active',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='articleFooter',
            field=models.CharField(default=1, max_length=150),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='body1',
            field=models.CharField(default=1, max_length=150),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='body1Image',
            field=models.CharField(default=1, max_length=150),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='body2',
            field=models.CharField(default=1, max_length=150),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='body2Image',
            field=models.CharField(default=1, max_length=150),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='order',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='subTitle',
            field=models.CharField(default=1, max_length=150),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='teaser',
            field=models.CharField(default=1, max_length=150),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='contentarticle',
            name='teaserImage',
            field=models.CharField(default=1, max_length=150),
            preserve_default=False,
        ),
    ]
