# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-06 22:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0028_merge_20170406_2131'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteBannerHeigth',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteBannerImg',
            field=models.ImageField(blank=True, null=True, upload_to='siteImages/'),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteBannerWidth',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteLogoPadding',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteMenuLeftPadding',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='body3Image',
            field=models.ImageField(blank=True, null=True, upload_to='articleImages/'),
        ),
    ]
