# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-22 20:04
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0007_sitemaininfo_recordreference'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sitemaininfo',
            name='active',
            field=models.IntegerField(default=0, unique=True),
        ),
    ]
