<footer class="mdl-mini-footer">
    <div class="mdl-mini-footer__left-section">
        (&copy;) 2017 - {{siteInfoData.siteName}} / OpenMinds
    </div>
    <div class="mdl-mini-footer__right-section">
        <ul class="mdl-mini-footer__link-list">
            <li>Telefone:  {{siteInfoData.sitePhone1}}</li>
            <li>Email: {{siteInfoData.siteEmail}}</li>
        </ul>
    </div>
</footer>

