# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-23 08:42
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0018_auto_20170322_2248'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='categoryitem',
            name='itemLayout',
        ),
    ]
