# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-11 09:19
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0033_auto_20170411_0919'),
    ]

    operations = [
        migrations.RenameField(
            model_name='sitemaininfo',
            old_name='allwaysDisplayDrawreMenu',
            new_name='allwaysDisplayDrawerMenu',
        ),
    ]
