# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-23 13:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0019_remove_categoryitem_itemlayout'),
    ]

    operations = [
        migrations.AlterField(
            model_name='categoryitem',
            name='itemTemplate',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Alternative itemTemplate (by default, the category name):'),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='body1',
            field=models.CharField(blank=True, max_length=450, null=True),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='body2',
            field=models.CharField(blank=True, max_length=450, null=True),
        ),
    ]
