# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-11 16:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0035_contentarticle_slug'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contentarticle',
            name='slug',
            field=models.SlugField(blank=True, null=True),
        ),
    ]
