# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-11 16:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0036_auto_20170411_1637'),
    ]

    operations = [
        migrations.AddField(
            model_name='categoryitem',
            name='itemReadMore',
            field=models.CharField(blank=True, default='Ver +', max_length=50, null=True, verbose_name="Label to 'Red More' buttom"),
        ),
    ]
